@@ -41,15 +41,15 @@
 #'   3D distance between points should be added to graph (default \code{FALSE}) 
 #'   \emph{or} a numeric vector of weights.
 #' @param directed Whether the resultant graph should be directed (default TRUE)
-#' @param vertex.attributes,graph.attributes List of named attributes to be 
-#'   added to the graph. The elements of \code{vertex.attributes} must be 
-#'   vectors whose length is compatible with the number of elements in the 
-#'   graph. See \code{\link[igraph]{set.vertex.attribute}} for details.
+#' @param vertex.attributes,graph.attributes List of named attributes to be
+#'   added to the graph. The elements of \code{vertex.attributes} must be
+#'   vectors whose length is compatible with the number of elements in the
+#'   graph. See \code{\link[igraph]{set_vertex_attr}} for details.
 #' @return an \code{igraph} object with additional class \code{ngraph}, having a
 #'   vertex for each entry in vertexlabels, each vertex having a \code{label} 
 #'   attribute. All vertices are included whether connected or not.
 #' @family neuron
-#' @seealso \code{\link{igraph}}, \code{\link[igraph]{set.vertex.attribute}},
+#' @seealso \code{\link{igraph}}, \code{\link[igraph]{set_vertex_attr}},
 #'   \code{\link{subset.neuron}} for example of graph-based manipulation of a
 #'   neuron.
 #' @export
@@ -86,10 +86,10 @@ ngraph<-function(el, vertexlabels, xyz=NULL, diam=NULL, directed=TRUE,
   }
   if(!is.null(diam)) igraph::V(g)$diam=diam
   for(n in names(vertex.attributes)){
-    g=igraph::set.vertex.attribute(g,name=n,value=vertex.attributes[[n]])
+    g=igraph:: set_vertex_attr(g,name=n,value=vertex.attributes[[n]])
   }
   for(n in names(graph.attributes)){
-    g=igraph::set.graph.attribute(g,name=n,value=graph.attributes[[n]])
+    g=igraph::set_graph_attr(g, name=n,value=graph.attributes[[n]])
   }
   class(g)=c("ngraph",class(g))
   g
@@ -137,10 +137,10 @@ as.ngraph.neuron<-function(x, directed=TRUE, method=c('swc','seglist'), ...){
 #' @export
 as.ngraph.igraph<-function(x, directed=TRUE, root, mode=c('out','in'), ...){
   if(inherits(x,'ngraph'))
-    if(igraph::is.directed(x)==directed) return(x)
+    if(igraph::is_directed(x)==directed) return(x)
   
-  if(igraph::is.directed(x) && !directed) x=as.undirected(x, ...)
-  else if(!igraph::is.directed(x) && directed) x=as.directed.usingroot(x, root, mode=mode, ...)
+  if(igraph::is_directed(x) && !directed) x=as.undirected(x, ...)
+  else if(!igraph::is_directed(x) && directed) x=as.directed.usingroot(x, root, mode=mode, ...)
   
   if(!inherits(x,'ngraph')){
     class(x)=c("ngraph",class(x))
@@ -151,11 +151,11 @@ as.ngraph.igraph<-function(x, directed=TRUE, root, mode=c('out','in'), ...){
 as.directed.usingroot<-function(g, root, mode=c('out','in')){
   mode=match.arg(mode)
   # make a directed graph _keeping any attributes_
-  if(!igraph::is.directed(g))
+  if(!igraph::is_directed(g))
     dg=igraph::as.directed(g, mode='arbitrary')
   else dg=g
-  dfs=igraph::graph.dfs(dg, root, unreachable=FALSE, dist=TRUE, mode='all')
-  el=igraph::get.edgelist(dg)
+  dfs=igraph::dfs(dg, root, unreachable=FALSE, dist=TRUE, mode='all')
+  el=igraph::as_edgelist(dg)
   
   connected_vertices=which(is.finite(dfs$order))
   edges_to_check=which(el[,1]%in%connected_vertices)
@@ -171,8 +171,8 @@ as.directed.usingroot<-function(g, root, mode=c('out','in')){
   if(any(same_dist)) warning(sum(same_dist)," edges connect vertices that are the same distance from the root => cycles.")
   edges_to_flip <- edges_to_check[if(mode=='out') parent_further else parent_closer]
   
-  dg=igraph::delete.edges(dg,edges_to_flip)
-  dg=igraph::add.edges(dg,t(el[edges_to_flip,2:1]))
+  dg=igraph::delete_edges(dg,edges_to_flip)
+  dg=igraph::add_edges(dg,t(el[edges_to_flip,2:1]))
   dg
 }
 
@@ -198,9 +198,9 @@ as.directed.usingroot<-function(g, root, mode=c('out','in')){
 #'   \item an integer vector of raw point indices (when \code{rval="ids"}).
 #'   
 #'   }
-#' @seealso \code{\link[igraph]{diameter}}, 
-#'   \code{\link[igraph]{shortest.paths}}, \code{\link{prune_strahler}} for 
-#'   removing lower order branches from a neuron, \code{\link{prune}} for 
+#' @seealso \code{\link[igraph]{diameter}},
+#'   \code{\link[igraph]{distances}}, \code{\link{prune_strahler}} for
+#'   removing lower order branches from a neuron, \code{\link{prune}} for
 #'   removing parts of a neuron by spatial criteria.
 #' @export
 #' @examples
@@ -220,9 +220,9 @@ as.directed.usingroot<-function(g, root, mode=c('out','in')){
 #' plot3d(Cell07PNs[[1]])
 #' plot3d(antispine, lwd=4, col='red')
 #' }
-#' 
-#' @importFrom igraph shortest.paths get.shortest.paths diameter get.diameter 
-#'   delete.vertices
+#'
+#' @importFrom igraph distances shortest_paths diameter get_diameter
+#'   delete_vertices
 #' @family neuron
 spine <- function(n, UseStartPoint=FALSE, SpatialWeights=TRUE, invert=FALSE,
                   rval=c("neuron", "length", "ids")) {
@@ -232,16 +232,16 @@ spine <- function(n, UseStartPoint=FALSE, SpatialWeights=TRUE, invert=FALSE,
     stop("invert=TRUE is not implemented for rval='length'")
   if(UseStartPoint) {
     # Find longest shortest path from given start point to all end points
-    lps=shortest.paths(graph = ng, n$StartPoint, to = n$EndPoints, 
+    lps= distances(graph = ng, n$StartPoint, to = n$EndPoints,
                        mode = 'all')
     if(rval=='length') return(max(lps))
     to=n$EndPoints[which.max(lps)]
-    longestpath=get.shortest.paths(ng, from = n$StartPoint, to = to, mode = 'all')$vpath[[1]]
+    longestpath=shortest_paths(ng, from = n$StartPoint, to = to, mode = 'all')$vpath[[1]]
   } else {
     if(rval=='length') {
       return(diameter(ng, directed=FALSE))
     } else {
-      longestpath=get.diameter(ng, directed=FALSE)
+      longestpath=get_diameter(ng, directed=FALSE)
     }
   }
   if(rval=='ids') {
@@ -277,7 +277,7 @@ spine <- function(n, UseStartPoint=FALSE, SpatialWeights=TRUE, invert=FALSE,
 #' @return \code{igraph} object containing only nodes of neuron keeping original
 #'   labels (\code{x$d$PointNo} => \code{V(g)$label}) and vertex indices 
 #'   (\code{1:nrow(x$d)} => \code{V(g)$vid)}.
-#' @importFrom igraph make_empty_graph add.edges E
+#' @importFrom igraph make_empty_graph add_edges E
 #' @export
 #' @examples 
 #' sg=segmentgraph(Cell07PNs[[1]])
@@ -314,9 +314,9 @@ segmentgraph<-function(x, weights=TRUE, segids=FALSE, exclude.isolated=FALSE,
   }
   if(weights){
     weights=seglengths(x, all=TRUE)
-    g=add.edges(g, elred, weight=weights, segid=segids)
+    g=add_edges(g, elred, weight=weights, segid=segids)
   } else {
-    g=add.edges(g, elred, segid=segids)
+    g=add_edges(g, elred, segid=segids)
   }
   
   if(include.xyz){
@@ -327,7 +327,7 @@ segmentgraph<-function(x, weights=TRUE, segids=FALSE, exclude.isolated=FALSE,
   if(exclude.isolated){
     # remove any points with no neighbours
     isolated_vertices=igraph::V(g)[igraph::degree(g)==0]
-    g=igraph::delete.vertices(graph=g,isolated_vertices)
+    g=igraph::delete_vertices(graph=g,isolated_vertices)
   }
   g
 }
@@ -351,7 +351,7 @@ segmentgraph<-function(x, weights=TRUE, segids=FALSE, exclude.isolated=FALSE,
 #' @seealso \code{\link{prune_strahler}}, a \code{\link{segmentgraph}} (a form
 #'   of \code{\link{ngraph}}) representation is used to calculate the Strahler 
 #'   order.
-#' @importFrom igraph graph.bfs neighborhood V
+#' @importFrom igraph bfs neighborhood V
 #' @return A list containing \itemize{
 #'   
 #'   \item points Vector of integer Strahler orders for each point in the neuron
@@ -365,7 +365,7 @@ strahler_order<-function(x){
   if(length(roots)>1)
     stop("strahler_order not yet defined for multiple subtrees")
   
-  b=graph.bfs(s, root=roots, mode = 'out', unreachable=F, father=T)
+  b=bfs(s, root=roots, mode = 'out', unreachable=F, father=T)
   
   # find neighbours for each node
   n=neighborhood(s, 1, mode='out')
@@ -498,15 +498,17 @@ prune_strahler<-function(x, orderstoprune=1:2, ...) {
 prune_vertices<-function(x, verticestoprune, invert=FALSE, ...) {
   g=as.ngraph(x)
   
-  # because igraph.vs sequences are atttached to a specific graph
+  # because igraph.vs sequences are attached to a specific graph
   if(inherits(verticestoprune, "igraph.vs")) 
     verticestoprune=as.integer(verticestoprune)
   if(invert) {
-    nvertices=nrow(xyzmatrix(x))
+    nvertices=igraph::vcount(g)
     verticestoprune=setdiff(seq_len(nvertices), verticestoprune)
+  } else {
+    verticestoprune=setdiff(verticestoprune, 0)
   }
-  dg=igraph::delete.vertices(g, verticestoprune)
-  # delete.vertices will return an igraph
+  dg=igraph::delete_vertices(g, verticestoprune)
+  # delete_vertices will return an igraph
   as.neuron(as.ngraph(dg), ...)
 }
 
@@ -543,10 +545,10 @@ prune_edges<-function(x, edges, invert=FALSE, ...) {
   
   if(invert) edges=setdiff(igraph::E(g), edges)
   
-  dg=igraph::delete.edges(g, edges = edges)
+  dg=igraph::delete_edges(g, edges = edges)
   
   # remove unreferenced vertices
-  dg=igraph::delete.vertices(dg, which(igraph::degree(dg, mode='all')==0))
+  dg=igraph::delete_vertices(dg, which(igraph::degree(dg, mode='all')==0))
   as.neuron(as.ngraph(dg), ...)
 }
 
